Area Splitter Example
===============================================================================

:download:`splitter.enaml <../../../examples/containers/splitter.enaml>`

.. literalinclude:: ../../../examples/containers/splitter.enaml
    :language: python

::

 $ enaml-run splitter.enaml

.. image:: images/splitter.png
